.. Django-Openhumans documentation master file, created by
   sphinx-quickstart on Wed Aug  1 00:11:49 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

django-open-humans
=============================================

``django-open-humans`` is a self-contained application for the `Django web framework <https://www.djangoproject.com/>`_.

This app includes the models & views needed to do social logins through `Open Humans <https://www.openhumans.org/>`_
as well as capabilities to message members and access/delete/upload files for them. It manages the *Oauth2* procedure and token refreshes.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules/introduction
   modules/getting-started
   modules/interactions
   modules/configuration
   modules/views
   modules/models


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
